@@ -29,6 +29,7 @@ from vyxal.LazyList import *
 NUMBER_TYPE = "number"
 SCALAR_TYPE = "scalar"
 VyList = Union[list, LazyList]
+VyIterable = Union[str, VyList]
 
 
 def case_of(value: str) -> int:
@@ -41,6 +42,17 @@ def case_of(value: str) -> int:
     return -1
 
 
+@lazylist
+def chop(it: VyIterable, n: int) -> LazyList:
+    """Chop `it` into `n` chunks."""
+    chunk_len = len(it) // n
+    left_over = len(it) % n
+    for i in range(n):
+        length = chunk_len + (1 if left_over > i else 0)
+        yield it[:length]
+        it = it[length:]
+
+
 @lazylist
 def collect_until_false(
     predicate: types.FunctionType,
@@ -119,6 +131,17 @@ def digits(num: NUMBER_TYPE) -> List[int]:
     return [int(let) if let not in "-." else let for let in str(num)]
 
 
+@lazylist
+def drop_while(vec, fun, ctx):
+    vec = iterable(vec, ctx=ctx)
+    t = True
+    for item in vec:
+        if not safe_apply(fun, item, ctx=ctx):
+            t = False
+        if not t:
+            yield item
+
+
 @lazylist
 def enumerate_md(
     haystack: VyList, _index_stack: tuple = (), include_all=False
@@ -162,9 +185,9 @@ def fixed_point(
     """Repeat function until the result is no longer unique.
     Uses initial as the initial value"""
     previous = None
-    current = simplify(initial)
+    current = initial
 
-    while previous != current:
+    while simplify(previous) != simplify(current):
         yield current
         previous = deep_copy(current)
         current = safe_apply(function, current, ctx=ctx)
@@ -189,7 +212,7 @@ def foldl(
     return working if working is not None else 0
 
 
-def format_string(pattern: str, data: Union[str, VyList]) -> str:
+def format_string(pattern: str, data: VyIterable) -> str:
     """Returns the pattern formatted with the given data. If the data is
     a string, then the string is reused if there is more than one % to
     be formatted. Otherwise (the data is a list), % are cyclically
@@ -510,6 +533,22 @@ def local_maxima(lhs: str) -> List[Union[int, float]]:
     return LazyList(z for z in zeros if second_dx.subs(x, z) < 0)
 
 
+def longest_suffix(a: VyIterable, b: VyIterable) -> VyIterable:
+    """Find the longest suffix of a pair of strings or lists.
+    If bothare strings, the result is a string."""
+    i = 1
+    while i <= len(a) and i <= len(b):
+        if a[-i] == b[-i]:
+            i += 1
+        else:
+            break
+    i -= 1
+    if i == 0:
+        return "" if isinstance(a, str) and isinstance(b, str) else []
+    else:
+        return b[-i:] if isinstance(a, str) else a[-i:]
+
+
 def keep(haystack: Any, needle: Any) -> Any:
     """Used for keeping only needle in haystack"""
     if isinstance(haystack, str):
@@ -624,26 +663,25 @@ def mold(
     VyList
     The content, molded into the shape.
     """
-    final = []
-    original, content = itertools.tee(content)
-    for item in shape:
-        temp = []
-        if isinstance(item, str) or is_sympy(item):
-            item = [item]
-        for _ in item:
-            obj = next(content, None)
-            if obj is None:
-                content = itertools.tee(original)[1]
-                obj = next(content)
-            temp.append(obj)
-        if temp:
-            if len(temp) == 1:
-                temp = deep_copy(temp[0])
-            else:
-                temp = deep_copy(temp)
-            final.append(temp)
+    # Because something needs to be mutated.
+    index = 0
 
-    return final
+    @lazylist
+    def _mold(content, shape):
+        nonlocal index
+        for item in shape:
+            if type(item) is list or type(item) is LazyList:
+                yield _mold(content, item)
+            else:
+                # This should work for infinite lists
+                # Because taking the length of one will hang
+                try:
+                    yield content[index]
+                except IndexError:
+                    yield content[index % len(content)]
+                index += 1
+
+    return _mold(content, shape)
 
 
 def mold_without_repeat(
@@ -664,21 +702,22 @@ def mold_without_repeat(
     VyList
     The content, molded into the shape.
     """
-    final = []
-    _, content = itertools.tee(content)
-    for item in shape:
-        temp = []
-        if isinstance(item, (int, str)):
-            item = [item]
-        for _ in item:
-            obj = next(content, None)
-            if obj is None:
-                break
-            temp.append(obj)
-        if temp:
-            final.append(temp[::])
+    index = 0
 
-    return final
+    @lazylist
+    def _mold(content, shape):
+        nonlocal index
+        for item in shape:
+            if type(item) is list or type(item) is LazyList:
+                yield _mold(content, item)
+            else:
+                try:
+                    yield content[index]
+                    index += 1
+                except IndexError:
+                    break  # We've reached the end of content, stop looping
+
+    return _mold(content, shape)
 
 
 def pad_to_square(array: VyList) -> VyList:
@@ -865,7 +904,7 @@ def simplify(value: Any) -> Union[int, float, str, list]:
     Simplify values.
     Turns sympy values into floats, including sympy values in lists
     """
-    if isinstance(value, (int, float, str)):
+    if value is None or isinstance(value, (int, float, str)):
         return value
     elif is_sympy(value):
         if value.is_real:
@@ -887,7 +926,7 @@ def stationary_points(lhs: str) -> List[Union[int, float]]:
     return LazyList(zeros)
 
 
-def suffixes(lhs: Union[str, VyList], ctx: Context) -> VyList:
+def suffixes(lhs: VyIterable, ctx: Context) -> VyList:
     """Returns a list of suffixes, including the original list"""
     if isinstance(lhs, str):
         return [lhs[-i:] for i in range(len(lhs), 0, -1)]
@@ -992,7 +1031,12 @@ def transpose(
     r = 0
     while True:
         if any(has_ind(row, r) for row in matrix):
-            yield gen_row(r)
+            this_row = gen_row(r)
+            if type(matrix[r]) is str:
+                yield "".join(this_row)
+            else:
+                yield this_row
+
         else:
             break
         r += 1
@@ -1113,6 +1157,18 @@ def vy_eval(item: str, ctx: Context) -> Any:
             return item
 
 
+def vy_floor_str_helper(item):
+    temp = ""
+    for char in item:
+        if char == "-" and temp == "":
+            temp += char
+        elif char.isdigit():
+            temp += char
+        elif char == "." and "." not in temp:
+            temp += char
+    return sympy.nsimplify(temp)
+
+
 @lazylist
 def vy_map(function, vector, ctx: Context = DEFAULT_CTX):
     """Apply function to every element of vector"""
