@@ -38,7 +38,7 @@ STRUCTURE_INFORMATION = {
 CLOSING_CHARACTERS = "".join([v[1] for v in STRUCTURE_INFORMATION.values()])
 OPENING_CHARACTERS = list(STRUCTURE_INFORMATION.keys())
 MONADIC_MODIFIERS = list("v⁽&~ßƒɖ") + ["¨=", "¨v", "¨£", "¨p"]
-DYADIC_MODIFIERS = list("₌‡₍")
+DYADIC_MODIFIERS = list("₌‡₍") + ["¨i"]
 TRIADIC_MODIFIERS = list("≬")
 # The modifiers are stored as lists to allow for potential digraph
 # modifiers.
@@ -256,13 +256,18 @@ def parse(
                 remaining[0],
                 (structure.RecurseStatement, structure.BreakStatement),
             ):
-                remaining[0].parent_structure = parent
+                remaining[0].parent_structure = structure.MonadicModifier
 
             if head.value == "⁽":
                 # 1-element lambda
                 structures.append(
                     structure.Lambda(DEFAULT_ARITY, [remaining[0]])
                 )
+            elif head.value == "ß":
+                # Conditional execute
+                # This is a bit of a hacky fix, as modifiers are not
+                # powerful enough to deal with this.
+                structures.append(structure.IfStatement([remaining[0]]))
             else:
                 structures.append(
                     structure.MonadicModifier(head.value, remaining[0])
@@ -274,17 +279,24 @@ def parse(
                 break
             remaining = parse(tokens)
 
+            if len(remaining) < 2:
+                remaining.append(
+                    structure.GenericStatement(
+                        [lexer.Token(lexer.TokenType.GENERAL, "\n")]
+                    )
+                )
+
             if isinstance(
                 remaining[0],
                 (structure.RecurseStatement, structure.BreakStatement),
             ):
-                remaining[0].parent_structure = parent
+                remaining[0].parent_structure = structure.DyadicModifier
 
             if isinstance(
                 remaining[1],
                 (structure.RecurseStatement, structure.BreakStatement),
             ):
-                remaining[1].parent_structure = parent
+                remaining[1].parent_structure = structure.DyadicModifier
 
             if head.value == "‡":
                 # 2-element lambda
@@ -293,6 +305,10 @@ def parse(
                         DEFAULT_ARITY, [remaining[0], remaining[1]]
                     )
                 )
+            elif head.value == "¨i":
+                structures.append(
+                    structure.IfStatement([remaining[0]], [remaining[1]])
+                )
             else:
                 structures.append(
                     structure.DyadicModifier(
@@ -309,19 +325,19 @@ def parse(
                 remaining[0],
                 (structure.RecurseStatement, structure.BreakStatement),
             ):
-                remaining[0].parent_structure = parent
+                remaining[0].parent_structure = structure.TriadicModifier
 
             if isinstance(
                 remaining[1],
                 (structure.RecurseStatement, structure.BreakStatement),
             ):
-                remaining[1].parent_structure = parent
+                remaining[1].parent_structure = structure.TriadicModifier
 
             if isinstance(
                 remaining[2],
                 (structure.RecurseStatement, structure.BreakStatement),
             ):
-                remaining[2].parent_structure = parent
+                remaining[2].parent_structure = structure.TriadicModifier
             if head.value == "≬":
                 # 3-element lambda
                 structures.append(
